==> openjdk-21_21.0.10~4ea.orig.tar.xz: openjdk-21-21.0.10~4ea/test/jdk/java/util/TimeZone/ListTimeZones.java <==
/*
 * Copyright (c) 2009, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * @test
 * @bug 6851214 8347841
 * @summary Allow 24:00 as a valid end/start DST time stamp
 * @run main ListTimeZones
 */

import java.time.ZoneId;
import java.util.*;
import java.util.function.Predicate;

public class ListTimeZones{
  public static void main(String[] args){
    Date date = new Date();
    String[] TimeZoneIds = Arrays.stream(TimeZone.getAvailableIDs())
            .filter(Predicate.not(ZoneId.SHORT_IDS::containsKey))
            .toArray(String[]::new);
    for(int i = 0; i < TimeZoneIds.length; i++){
      TimeZone tz = TimeZone.getTimeZone(TimeZoneIds[i]);
      Calendar calendar = new GregorianCalendar(tz);
      String calString = calendar.toString();
    }
  }
}

==> openjdk-26_26~17ea.orig.tar.xz: openjdk-26-26~17ea/test/jdk/java/util/TimeZone/ListTimeZones.java <==
/*
 * Copyright (c) 2009, 2025, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

/**
 * @test
 * @bug 6851214 8347841 8347955
 * @summary Allow 24:00 as a valid end/start DST time stamp
 * @run main ListTimeZones
 */

import java.time.ZoneId;
import java.util.*;
import java.util.function.Predicate;

public class ListTimeZones{
  public static void main(String[] args){
    Date date = new Date();
    String[] TimeZoneIds = TimeZone.availableIDs()
            .filter(Predicate.not(ZoneId.SHORT_IDS::containsKey))
            .toArray(String[]::new);
    for(int i = 0; i < TimeZoneIds.length; i++){
      TimeZone tz = TimeZone.getTimeZone(TimeZoneIds[i]);
      Calendar calendar = new GregorianCalendar(tz);
      String calString = calendar.toString();
    }
  }
}
